@@ -11,18 +11,18 @@
 # SPDX-License-Identifier: GPL-3.0
 
 esyd() {
-    local cmd="${1}"
+    cmd="${1}"
 
     shift
     case "${cmd}" in
     api)
-        echo -n 3
+        printf '%d' 3
         ;;
     check)
         test -c /dev/syd
         ;;
     panic|reset|stat)
-        [ -c /dev/syd/${cmd} ]
+        [ -c /dev/syd/"${cmd}" ]
         ;;
     load)
         if [ ${#} -ne 1 ]; then
@@ -42,41 +42,17 @@ esyd() {
         ;;
     info)
         if [ -c /dev/syd ]; then
-            if command -v jq >/dev/null 2>&1; then
-                local out
-                out=$(mktemp)
-                if [ -n "$BASH_VERSION" ]; then
-                    # We're in Bash
-                    # This works with lock:exec
-                    IFS=$'\n' readarray -t syd < /dev/syd
-                    echo "${syd[*]}" > "${out}"
-                elif [ -n "$ZSH_VERSION" ]; then
-                    syd=$(</dev/syd)
-                    echo "${syd}" > "${out}"
-                else
-                    # Fallback for POSIX sh
-                    # This needs lock:off, doesn't work with lock:exec
-                    cat /dev/syd > "${out}"
-                fi
+            # Note we cannot spawn a subshell here,
+            # while reading from `/dev/syd` otherwise
+            # this will break with lock:exec.
+            while IFS= read -r dat || [ -n "${dat}" ]; do
+                syd="${syd}${dat}"
+            done </dev/syd
 
-                jq "${@}" < "${out}"
-                r=$?
-                rm -f "${out}"
-                return $r
+            if command -v jq >/dev/null 2>&1; then
+                printf '%s' "${syd}" | jq "${@}"
             else
-                if [ -n "$BASH_VERSION" ]; then
-                    # We're in Bash
-                    # This works with lock:exec
-                    IFS=$'\n' readarray -t syd < /dev/syd
-                    echo "${syd[*]}"
-                elif [ -n "$ZSH_VERSION" ]; then
-                    syd=$(</dev/syd)
-                    echo "${syd}"
-                else
-                    # Fallback for POSIX sh
-                    # This needs lock:off, doesn't work with lock:exec
-                    cat /dev/syd
-                fi
+                printf '%s' "${syd}"
             fi
         else
             return 1
@@ -132,7 +108,7 @@ esyd() {
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
-        [ -c "$(syd-exec ${@})" ]
+        [ -c "$(syd-exec "${@}")" ]
         ;;
     force)
         if [ ${#} -ne 3 ]; then
@@ -285,6 +261,15 @@ esyd() {
     disable_mkdir)
         [ -c '/dev/syd/sandbox/mkdir:off' ]
         ;;
+    enabled_rmdir)
+        [ -c '/dev/syd/sandbox/rmdir?' ]
+        ;;
+    enable_rmdir)
+        [ -c '/dev/syd/sandbox/rmdir:on' ]
+        ;;
+    disable_rmdir)
+        [ -c '/dev/syd/sandbox/rmdir:off' ]
+        ;;
     enabled_chown)
         [ -c '/dev/syd/sandbox/chown?' ]
         ;;
@@ -390,21 +375,17 @@ esyd() {
             return 1
         fi
         # allow is shorthand for all glob capabilities.
-        for capability in stat read write ioctl create delete rename symlink truncate chdir readdir mkdir chown chgrp chmod chattr chroot mkdev mkfifo mktemp; do
-            _esyd_path "allow/${capability}" '+' "${@}"
-        done
+        _esyd_path "allow/all" '+' "${@}"
         ;;
     disallow|disallow_path)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
         # disallow is shorthand for all glob capabilities.
-        for capability in stat read write ioctl create delete rename symlink truncate chdir readdir mkdir chown chgrp chmod chattr chroot mkdev mkfifo mktemp; do
-            _esyd_path "allow/${capability}" "${op}" "${@}"
-        done
+        _esyd_path "allow/all" "${op}" "${@}"
         ;;
     deny|deny_path)
         if [ ${#} -lt 1 ]; then
@@ -412,21 +393,17 @@ esyd() {
             return 1
         fi
         # deny is shorthand for all glob capabilities.
-        for capability in stat read write ioctl create delete rename symlink truncate chdir readdir mkdir chown chgrp chmod chattr chroot mkdev mkfifo mktemp; do
-            _esyd_path "deny/${capability}" '+' "${@}"
-        done
+        _esyd_path "deny/all" '+' "${@}"
         ;;
     nodeny|nodeny_path)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
         # nodeny is shorthand for all glob capabilities.
-        for capability in stat read write ioctl create delete rename symlink truncate chdir readdir mkdir chown chgrp chmod chattr chroot mkdev mkfifo mktemp; do
-            _esyd_path "deny/${capability}" "${op}" "${@}"
-        done
+        _esyd_path "deny/all" "${op}" "${@}"
         ;;
     allow_stat)
         if [ ${#} -lt 1 ]; then
@@ -436,8 +413,8 @@ esyd() {
         _esyd_path 'allow/stat' '+' "${@}"
         ;;
     disallow_stat)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -452,8 +429,8 @@ esyd() {
         _esyd_path 'deny/stat' '+' "${@}"
         ;;
     nodeny_stat)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -468,8 +445,8 @@ esyd() {
         _esyd_path 'allow/read' '+' "${@}"
         ;;
     disallow_read)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -484,8 +461,8 @@ esyd() {
         _esyd_path 'deny/read' '+' "${@}"
         ;;
     nodeny_read)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -500,8 +477,8 @@ esyd() {
         _esyd_path 'allow/write' '+' "${@}"
         ;;
     disallow_write)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -516,8 +493,8 @@ esyd() {
         _esyd_path 'deny/write' '+' "${@}"
         ;;
     nodeny_write)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -532,8 +509,8 @@ esyd() {
         _esyd_path 'allow/exec' '+' "${@}"
         ;;
     disallow_exec)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -548,8 +525,8 @@ esyd() {
         _esyd_path 'deny/exec' '+' "${@}"
         ;;
     nodeny_exec)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -564,8 +541,8 @@ esyd() {
         _esyd_path 'allow/ioctl' '+' "${@}"
         ;;
     disallow_ioctl)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -580,8 +557,8 @@ esyd() {
         _esyd_path 'deny/ioctl' '+' "${@}"
         ;;
     nodeny_ioctl)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -596,8 +573,8 @@ esyd() {
         _esyd_path 'allow/create' '+' "${@}"
         ;;
     disallow_create)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -612,8 +589,8 @@ esyd() {
         _esyd_path 'deny/create' '+' "${@}"
         ;;
     nodeny_create)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -628,8 +605,8 @@ esyd() {
         _esyd_path 'allow/delete' '+' "${@}"
         ;;
     disallow_delete)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -644,8 +621,8 @@ esyd() {
         _esyd_path 'deny/delete' '+' "${@}"
         ;;
     nodeny_delete)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -660,8 +637,8 @@ esyd() {
         _esyd_path 'allow/rename' '+' "${@}"
         ;;
     disallow_rename)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -676,8 +653,8 @@ esyd() {
         _esyd_path 'deny/rename' '+' "${@}"
         ;;
     nodeny_rename)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -692,8 +669,8 @@ esyd() {
         _esyd_path 'allow/symlink' '+' "${@}"
         ;;
     disallow_symlink)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -708,8 +685,8 @@ esyd() {
         _esyd_path 'deny/symlink' '+' "${@}"
         ;;
     nodeny_symlink)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -724,8 +701,8 @@ esyd() {
         _esyd_path 'allow/truncate' '+' "${@}"
         ;;
     disallow_truncate)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -740,8 +717,8 @@ esyd() {
         _esyd_path 'deny/truncate' '+' "${@}"
         ;;
     nodeny_truncate)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -756,8 +733,8 @@ esyd() {
         _esyd_path 'allow/chdir' '+' "${@}"
         ;;
     disallow_chdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -772,8 +749,8 @@ esyd() {
         _esyd_path 'deny/chdir' '+' "${@}"
         ;;
     nodeny_chdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -788,8 +765,8 @@ esyd() {
         _esyd_path 'allow/readdir' '+' "${@}"
         ;;
     disallow_readdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -804,8 +781,8 @@ esyd() {
         _esyd_path 'deny/readdir' '+' "${@}"
         ;;
     nodeny_readdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -820,8 +797,8 @@ esyd() {
         _esyd_path 'allow/mkdir' '+' "${@}"
         ;;
     disallow_mkdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -836,14 +813,46 @@ esyd() {
         _esyd_path 'deny/mkdir' '+' "${@}"
         ;;
     nodeny_mkdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
         _esyd_path 'deny/mkdir' "${op}" "${@}"
         ;;
+    allow_rmdir)
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'allow/rmdir' '+' "${@}"
+        ;;
+    disallow_rmdir)
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'allow/rmdir' "${op}" "${@}"
+        ;;
+    deny_rmdir)
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'deny/rmdir' '+' "${@}"
+        ;;
+    nodeny_rmdir)
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'deny/rmdir' "${op}" "${@}"
+        ;;
     allow_chown)
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
@@ -852,8 +861,8 @@ esyd() {
         _esyd_path 'allow/chown' '+' "${@}"
         ;;
     disallow_chown)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -868,8 +877,8 @@ esyd() {
         _esyd_path 'deny/chown' '+' "${@}"
         ;;
     nodeny_chown)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -884,8 +893,8 @@ esyd() {
         _esyd_path 'allow/chgrp' '+' "${@}"
         ;;
     disallow_chgrp)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -900,8 +909,8 @@ esyd() {
         _esyd_path 'deny/chgrp' '+' "${@}"
         ;;
     nodeny_chgrp)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -916,8 +925,8 @@ esyd() {
         _esyd_path 'allow/chmod' '+' "${@}"
         ;;
     disallow_chmod)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -932,8 +941,8 @@ esyd() {
         _esyd_path 'deny/chmod' '+' "${@}"
         ;;
     nodeny_chmod)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -948,8 +957,8 @@ esyd() {
         _esyd_path 'allow/chattr' '+' "${@}"
         ;;
     disallow_chattr)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -964,8 +973,8 @@ esyd() {
         _esyd_path 'deny/chattr' '+' "${@}"
         ;;
     nodeny_chattr)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -980,8 +989,8 @@ esyd() {
         _esyd_path 'allow/chroot' '+' "${@}"
         ;;
     disallow_chroot)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -996,8 +1005,8 @@ esyd() {
         _esyd_path 'deny/chroot' '+' "${@}"
         ;;
     nodeny_chroot)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1012,8 +1021,8 @@ esyd() {
         _esyd_path 'allow/utime' '+' "${@}"
         ;;
     disallow_utime)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1028,8 +1037,8 @@ esyd() {
         _esyd_path 'deny/utime' '+' "${@}"
         ;;
     nodeny_utime)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1044,8 +1053,8 @@ esyd() {
         _esyd_path 'allow/mkdev' '+' "${@}"
         ;;
     disallow_mkdev)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1060,8 +1069,8 @@ esyd() {
         _esyd_path 'deny/mkdev' '+' "${@}"
         ;;
     nodeny_mkdev)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1076,8 +1085,8 @@ esyd() {
         _esyd_path 'allow/mkfifo' '+' "${@}"
         ;;
     disallow_mkfifo)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1092,8 +1101,8 @@ esyd() {
         _esyd_path 'deny/mkfifo' '+' "${@}"
         ;;
     nodeny_mkfifo)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1108,8 +1117,8 @@ esyd() {
         _esyd_path 'allow/mktemp' '+' "${@}"
         ;;
     disallow_mktemp)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1124,8 +1133,8 @@ esyd() {
         _esyd_path 'deny/mktemp' '+' "${@}"
         ;;
     nodeny_mktemp)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1133,9 +1142,9 @@ esyd() {
         _esyd_path 'deny/mktemp' "${op}" "${@}"
         ;;
     allow_net)
-        local op='-'
-        local c='allow/net/bind'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        c='allow/net/bind'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         case "${1}" in
         '--connect')
             c='allow/net/connect'
@@ -1151,9 +1160,9 @@ esyd() {
         _esyd_net "${c}" '+' "${@}"
         ;;
     disallow_net)
-        local op='-'
-        local c='allow/net/bind'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        c='allow/net/bind'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         case "${1}" in
         '--connect')
             c='allow/net/connect'
@@ -1169,9 +1178,9 @@ esyd() {
         _esyd_net "${c}" "${op}" "${@}"
         ;;
     deny_net)
-        local op='-'
-        local c='deny/net/bind'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        c='deny/net/bind'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         case "${1}" in
         '--connect')
             c='allow/net/connect'
@@ -1187,9 +1196,9 @@ esyd() {
         _esyd_net "${c}" '+' "${@}"
         ;;
     nodeny_net)
-        local op='-'
-        local c='deny/net/bind'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        c='deny/net/bind'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         case "${1}" in
         '--connect')
             c='allow/net/connect'
@@ -1209,18 +1218,18 @@ esyd() {
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
-        for capability in stat read write ioctl create delete rename symlink truncate chdir readdir mkdir chown chgrp chmod chattr chroot mkdev mkfifo mktemp; do
+        for capability in stat read write ioctl create delete rename symlink truncate chdir readdir mkdir rmdir chown chgrp chmod chattr chroot mkdev mkfifo mktemp; do
             _esyd_path "filter/${capability}" '+' "${@}" || return 1
         done
         ;;
     rmfilter|rmfilter_path)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
-        for capability in stat read write ioctl create delete rename symlink truncate chdir readdir mkdir chown chgrp chmod chattr chroot mkdev mkfifo mktemp; do
+        for capability in stat read write ioctl create delete rename symlink truncate chdir readdir mkdir rmdir chown chgrp chmod chattr chroot mkdev mkfifo mktemp; do
             _esyd_path "filter/${capability}" "${op}" "${@}" || return 1
         done
         ;;
@@ -1232,8 +1241,8 @@ esyd() {
         _esyd_path 'filter/stat' '+' "${@}"
         ;;
     rmfilter_stat)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1248,8 +1257,8 @@ esyd() {
         _esyd_path 'filter/read' '+' "${@}"
         ;;
     rmfilter_read)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1264,8 +1273,8 @@ esyd() {
         _esyd_path 'filter/write' '+' "${@}"
         ;;
     rmfilter_write)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1280,8 +1289,8 @@ esyd() {
         _esyd_path 'filter/exec' '+' "${@}"
         ;;
     rmfilter_exec)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1296,8 +1305,8 @@ esyd() {
         _esyd_path 'filter/ioctl' '+' "${@}"
         ;;
     rmfilter_ioctl)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1312,8 +1321,8 @@ esyd() {
         _esyd_path 'filter/create' '+' "${@}"
         ;;
     rmfilter_create)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1328,8 +1337,8 @@ esyd() {
         _esyd_path 'filter/delete' '+' "${@}"
         ;;
     rmfilter_delete)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1344,8 +1353,8 @@ esyd() {
         _esyd_path 'filter/rename' '+' "${@}"
         ;;
     rmfilter_rename)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1360,8 +1369,8 @@ esyd() {
         _esyd_path 'filter/symlink' '+' "${@}"
         ;;
     rmfilter_symlink)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1376,8 +1385,8 @@ esyd() {
         _esyd_path 'filter/truncate' '+' "${@}"
         ;;
     rmfilter_truncate)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1392,8 +1401,8 @@ esyd() {
         _esyd_path 'filter/chdir' '+' "${@}"
         ;;
     rmfilter_chdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1408,8 +1417,8 @@ esyd() {
         _esyd_path 'filter/readdir' '+' "${@}"
         ;;
     rmfilter_readdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1424,29 +1433,29 @@ esyd() {
         _esyd_path 'filter/mkdir' '+' "${@}"
         ;;
     rmfilter_mkdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
         _esyd_path 'filter/mkdir' "${op}" "${@}"
         ;;
-    addfilter_mkdir)
+    addfilter_rmdir)
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
-        _esyd_path 'filter/mkdir' '+' "${@}"
+        _esyd_path 'filter/rmdir' '+' "${@}"
         ;;
-    rmfilter_mkdir)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+    rmfilter_rmdir)
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
-        _esyd_path 'filter/mkdir' "${op}" "${@}"
+        _esyd_path 'filter/rmdir' "${op}" "${@}"
         ;;
     addfilter_chown)
         if [ ${#} -lt 1 ]; then
@@ -1456,8 +1465,8 @@ esyd() {
         _esyd_path 'filter/chown' '+' "${@}"
         ;;
     rmfilter_chown)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1472,8 +1481,8 @@ esyd() {
         _esyd_path 'filter/chgrp' '+' "${@}"
         ;;
     rmfilter_chgrp)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1488,8 +1497,8 @@ esyd() {
         _esyd_path 'filter/chmod' '+' "${@}"
         ;;
     rmfilter_chmod)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1504,8 +1513,8 @@ esyd() {
         _esyd_path 'filter/chattr' '+' "${@}"
         ;;
     rmfilter_chattr)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1520,8 +1529,8 @@ esyd() {
         _esyd_path 'filter/chroot' '+' "${@}"
         ;;
     rmfilter_chroot)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1536,8 +1545,8 @@ esyd() {
         _esyd_path 'filter/utime' '+' "${@}"
         ;;
     rmfilter_utime)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1552,8 +1561,8 @@ esyd() {
         _esyd_path 'filter/mkdev' '+' "${@}"
         ;;
     rmfilter_mkdev)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1568,8 +1577,8 @@ esyd() {
         _esyd_path 'filter/mkfifo' '+' "${@}"
         ;;
     rmfilter_mkfifo)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1584,8 +1593,8 @@ esyd() {
         _esyd_path 'filter/mktemp' '+' "${@}"
         ;;
     rmfilter_mktemp)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1600,8 +1609,8 @@ esyd() {
         _esyd_net 'filter/net' '+' "${@}"
         ;;
     rmfilter_net)
-        local op='-'
-        [ "${1}" == '--all' ] && op='^' && shift
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
@@ -1739,6 +1748,12 @@ enable_mkdir
     Enable mkdir sandboxing
 disable_mkdir
     Disable mkdir sandboxing
+enabled_rmdir
+    Return true if rmdir sandboxing is enabled
+enable_rmdir
+    Enable rmdir sandboxing
+disable_rmdir
+    Disable rmdir sandboxing
 enabled_chown
     Return true if chown sandboxing is enabled
 enable_chown
@@ -1917,6 +1932,14 @@ deny_mkdir glob
     Deny the given glob pattern for mkdir sandboxing
 nodeny_mkdir [--all] glob
     Removes the given glob pattern from the denylist for mkdir sandboxing
+allow_rmdir glob
+    Allow the given glob pattern for rmdir sandboxing
+disallow_rmdir [--all] glob
+    Removes the given glob pattern from the allowlist for rmdir sandboxing
+deny_rmdir glob
+    Deny the given glob pattern for rmdir sandboxing
+nodeny_rmdir [--all] glob
+    Removes the given glob pattern from the denylist for rmdir sandboxing
 allow_chown glob
     Allow the given glob pattern for chown sandboxing
 disallow_chown [--all] glob
@@ -2056,6 +2079,10 @@ addfilter_mkdir glob
     Adds the given glob pattern to the list of access violation filters for mkdir sandboxing
 rmfilter_mkdir [--all] glob
     Removes the given glob pattern from the list of access violation filters for mkdir sandboxing
+addfilter_rmdir glob
+    Adds the given glob pattern to the list of access violation filters for rmdir sandboxing
+rmfilter_rmdir [--all] glob
+    Removes the given glob pattern from the list of access violation filters for rmdir sandboxing
 addfilter_chown glob
     Adds the given glob pattern to the list of access violation filters for chown sandboxing
 rmfilter_chown [--all] glob
@@ -2136,8 +2163,8 @@ EOF
 
 _esyd_path()
 {
-    local cmd="${1}"
-    local op="${2}"
+    cmd="${1}"
+    op="${2}"
 
     case "${op}" in
     '+'|'-')
@@ -2150,8 +2177,7 @@ _esyd_path()
 
     shift 2
 
-    local ret=0
-    local path
+    ret=0
     for path in "${@}"; do
         case "${path}" in
         /*)
@@ -2168,8 +2194,8 @@ _esyd_path()
 
 _esyd_net()
 {
-    local cmd="${1}"
-    local op="${2}"
+    cmd="${1}"
+    op="${2}"
 
     case "${op}" in
     '+'|'-')
@@ -2182,7 +2208,7 @@ _esyd_net()
 
     shift 2
 
-    local ret=0
+    ret=0
     while [ ${#} -gt 0 ] ; do
         # syd does input validation so we don't do any here.
         [ -c "/dev/syd/${cmd}${op}${1}" ] || ret=$?
